{% extends "base_view.html" %}

{% block title %} meliza-lab : bird colony {% endblock %}

{% block content %}

<!-- <h2>Current denizens</h2> -->

<!-- <table class="table table-striped table-condensed"> -->
<!--   <thead> -->
<!--     <th>Age</th> -->
<!--     <th>Species</th> -->
<!--     <th>Count</th> -->
<!--   </thead> -->
<!--   <tbody> -->
<!--     {% for group in groups %} -->
<!--     <tr> -->
<!--       <td>{{ group.name }}</td> -->
<!--       <td>{{ group.species }}</td> -->
<!--       <td>{{ group.count }}</td> -->
<!--     </tr> -->
<!--     {% endfor %} -->
<!--   </tbody> -->
<!-- </table> -->

<h2>Actions</h2>

<p><a href="{% url 'birds:event_summary' today.year today.month %}">summary for this month</a></p>
<p><a href="{% url 'birds:event_summary' lastmonth.year lastmonth.month %}">summary for last month</a></p>
<p><a href="{% url 'birds:birds_living' %}">list living birds</a></p>
<p><a href="{% url 'birds:events' %}">list recent events</a></p>
<p><a href="{% url 'birds:new_bird' %}">add new bird</a></p>
{% endblock %}
