<table class="table table-striped table-condensed">
  <thead>
    <th>Name</th>
    <th>Species</th>
    <th>Band</th>
    <th>Sex</th>
    <th>Age (days)</th>
    <th>Alive</th>
    <th>Children</th>
    <th>UUID</th>
    <th>Reserved</th>
  </thead>
  <tbody>
    {% for bird in bird_list %}
        <tr>
          <td><a href="{{ bird.get_absolute_url }}">{{ bird.name }}</a></td>
          <td>{{ bird.species }}</td>
          <td>{{ bird.band }}</td>
          <td>{{ bird.sex }}</td>
          <td>{{ bird.age_days }}</td>
          <td>{{ bird.alive}}</td>
          <td>{{ bird.nchildren|last}}</td>
          <td>{{ bird.uuid }}</td>
          <td>{% if bird.reserved_by %}{{ bird.reserved_by }}{% endif %}</td>
          <td></td>
        </tr>
    {% endfor %}
  </tbody>
</table>
